.. header:: Steunpunt Survey-instrumenten

*************************************
User Manual Content Management System
*************************************

.. rubric:: version 0.1

.. rubric:: CONCEPT

.. contents:: Table of Contents
   :depth: 2

=======
General
=======

   This User Manual is also available to download on:

   http://www.oira.osha.europa.eu

   Note: the images in this User Manual are generally more legible in printed
   form (preferably in colour) than on the screen.

--------------------------
Requesting a Login Account
--------------------------

   To request a Login Account, send an email to OIRA Support
   (info@osha.europa.eu) with the following information:

     * The name of your sector (as known by the general public).

     * Your fore- and surname.

     * Your email address.

     * Your preferred password for the CMS (with a minimum of 5 characters,
       the user name will be confirmed by the EU-OSHA Oira Team)

   In addition, clearly state in your email that you are requesting an
   account for the OiRA Tool, and explain why.

   We will use this information to create your sector and will link this your
   Login Account.

   Once your account has been created you will receive an email, at the
   provided address, containing the login information. Please note: Both your
   user name and password are case sensitive!

   In addition to the login information you will receive an agreement, which
   determines the Terms and Conditions for using the CMS (such as: full
   public access, responsibility to keep the sector's Survey up-to-date). The
   agreement has to be signed and returned within three weeks.

----------
Logging in 
----------

   Preferred web browsers are: Mozilla Firefox version 3.6, or any later
   version, or Google Chrome (both are available to download for free).
   Alternatively Microsoft Internet Explorer version 7, or any later version.

   You start on: admin.oira.osha.europa.eu

   .. image:: images/editor/editor_1_login.png

   And login with your User Name and Password.

   Did you forget your password? Check the confirmation email or click at the
   bottom of the page on 'request a password reset'.

   Then add your user name and click on 'Send'.

   .. image:: images/editor/editor_2_password_reset.png

   The password will be sent to the email address you provided.

   .. image:: images/editor/editor_3_password_reset_confirmation.png

   If your login has been successful, a green bar with a confirmation will
   appear.

   The CMS uses these bars to communicate system notifications to you.

   .. image:: images/editor/editor_4_loggedin.png

   After logging in, you will be brought to a page with an overview of the
   Risk Assessment Tool for your sector. Here you can: click on a tool to
   amend it, or start a new survey by clicking on --> 'Add
   New survey' at the bottom of the page.

------------------------------------
Creating and completing a new Survey
------------------------------------

   After clicking on 'Add New survey' (see image above) you will be brought
   to the page below:

   .. image:: images/editor/editor_5_addsurvey.png

   When creating a new survey you can choose from the following three
   options:

    1. Start with a blank survey

    2. Base my survey on an existing survey of my organisation.

    3. Base my survey on an existing survey of another organisation.

   ad 1) Starting with a blank survey is particularly useful when you already
   have a paper-based survey for your organisation and would like to transfer
   this to the digital system.

   ad 2) This option is recommended when you are: (a) planning to revise the
   contents of your Survey and/or (b) would like to add new modules. This
   option is also useful for organisations which manage multiple
   (sector-)Surveys, of which the base modules are applicable to other
   Surveys.

   NB: When dealing with minor amendments, e.g. typos, it would be best to
   implement these in the existing Survey and simply republish it.

   NB: When the questions won't be amended, but, for instance, only the
   clarifications you can simply create a new version (a copy) of the
   existing Survey (also see: --> version management).

   ad 3) You can decide which existing Survey is most suitable for your
   sector. You can copy and modify it, and thus avoid having to create one
   from scratch. You have to determine the amendments for your own sector.
   For example, the butcher could copy and modify the Survey of the fish
   retailer.

   In addition to the Survey of a specific sector, you can also use the
   so-called generic checklist as a starting point. It's slightly more
   general, but it does contain all the relevant aspects for an Survey. The
   base-Survey has been an inspiration for many sector-specific Digital
   Surveys and is considered to be a suitable starting point.

   The base-Survey provides solutions at module level, which you can copy and
   modify if needed. It doesn't provide solutions at a question level. In
   addition, most modules of the base-Survey start with a 'filter question',
   which determines whether the situation concerned will be applicable to the
   end-user.(For more information on solutions at module/question level, see
   chapter 6.4)

   NB: After you've copied an existing Survey, any changes made to the
   'source-Survey' will not automatically be reflected in your own Survey.
   When, for example, the butcher has copied the Survey of the fish retailer
   and the fish retailer implements changes in their Survey afterwards, these
   changes will not appear in the Survey of the butcher.

   If you would like to copy the Survey of another sector as a starting
   point, you need to first select the country in the drop-down menu and
   subsequently the sector of your choice.

   When this sector provides more than one version, you can view these
   versions and select one.

   Give the Survey a name (title). This name will be shown to the end-user in
   the overview. Tip: The overview is in alphabetical order, so make sure to
   choose a name based on your sector, for example 'New Risk Assessment
   2010'.

   Then click on 'Save Changes' at the bottom of the page.

   Your Survey will then be created. Please note that this can take a while
   if you've chosen to use a copy of an existing Survey.

   In case of a new (blank) Survey you will see a screen as shown below:

   .. image:: images/editor/editor_6_newsurvey.png

====================
Modifying the Survey
====================

   On the main page (top navigation tree) you indicate those things, that are
   of priority for the Survey as a whole. You can modify these later, by
   clicking on 'Edit':

     * Name: you can modify the name of the Survey. The name you enter here
       will not be visible to the end-user and is mainly intended to
       facilitate you in managing the version. For the first version (new
       Survey) the name 'Standard' will automatically be selected.

     * Description: short content description.

     * Introduction: this is for a (brief!) introduction, which will be shown
       to the end-user on the Survey start page.

   If you don't enter any text here, the standard text will be used.

     * The evaluation can be skipped: when you select this option, the
       end-user is able to complete the evaluation but won't get a warning
       when this step is skipped. If you don't select this option the
       evaluation will become obligatory, which means that the end-user won't
       be able to fast-track to the 'Action Plan'.

     * Language: choose 'English' in the drop-down menu.

     * Classification Code: we plan to show the sector codes for all of
       Europe here in the near future (according to the NACE-standard). For
       now you can write the name of your sector.

   .. image:: images/editor/editor_7_survey_version_edit.png

   In the larger fields you can add both normal and formatted text. You will
   be able to identify this option from the grey bar at the top of the page
   (the 'formatting bar'). The formatting bar will only be visible when
   you're in a field where formatting is possible.

   We would recommend you to type the text into the field without formatting.
   When you paste text into the field from another program, e.g. Word, the
   font used in Word will automatically be copied over. You will then not be
   able to change the font with the formatting bar. Word generates code to
   convert the text to html (which is used in the CMS).You will not see this
   code when you paste the text from Word into the CMS, but it does exist
   'underneath' the text. Hyperlinks also have a fixed format in Word (colour
   and underlining), which is unchangeable after pasting into the CMS. It's
   best to implement hyperlinks after the text has been entered correctly
   into the CMS (see the explanation further below for creating links).

   Therefore, please keep in mind that pasting text from Word can cause
   unexpected effects. In addition, pasting text from programs other than
   Word can cause similar unexpected effects. This applies to all fields in
   the CMS where formatting is possible. This is why we advise you to type
   the text into the field without formatting, instead of pasting from Word.
   When you do decide to paste from Word, it's best to ensure that all the
   text is already formatted correctly (font, size and colour). In addition,
   all text you paste in should ideally have consistent font, size and colour
   properties.

   The formatting bar offers the following options:

     * Bold (fat): you select (by dragging the mouse) a portion of text and
       click on 'B' in the formatting bar above the field.

     * Selecting the same text again and re-clicking 'B' will undo the bold
       font (this applies to all formatting options).

     * Italic (italicized): you select (by dragging the mouse) a portion of
       text and click on the 'I' in the formatting bar above the field. NB:
       Italicized text is generally not very legible on a screen.

     * Bullet points: you select the required lines and click on the icon
       with the dots.

     * Numbered list: you select the required lines and click on the icon
       with '1-2'.

     * Hyperlink (to a website): first type the text on which you would like
       to apply the hyperlink, for example: 'Also see this website'.
       Subsequently you select the text (by dragging the mouse). You then
       click on the button with the chain icon in the formatting bar. A new
       screen will then open:

     .. image:: images/editor/editor_8_place_a_link.png
       
     * At 'URL' you enter the web address, this must
       start with: 'http://'. Subsequently, you enter a title and indicate
       whether the link should open in a new screen by selecting the box.
       Then click on 'Save'. The link will appear as underlined text. Modify
       the link:: double click on the link. Delete the link: delete the linked
       word and retype it.

   NB: URLs are the way to link to documents from the sector, which you want
   to add to the Survey. For example: concept plans, concept drafts, -->
   the CLA, etc. Simply place the documents onto a website
   and create a hyperlink to the site in the Survey.

     * NB: If you would like to offer actual documents (e.g. Word or PDF
       files) on your Survey, you first have to place the documents onto a
       website (e.g. the site of your sector's organisation) and then create
       a link to these files as described above.

   With 'Ctrl-z' you can undo formatting and textual changes you made in the
   CMS field (multiple changes can be undone, as long as you haven't clicked
   'Save').

   In addition, you can click the right button of your mouse when you are in
   a field, which will provide you with an applicable menu. When you select a
   word you will also see options such as: cut, copy, paste, etc.

   Alternatively, you can use the following keyboard shortcuts:

     * Copy: Ctrl-c.

     * Paste: Ctrl-v.

     * Cut: Ctrl-x.

     * Select all: Ctrl-a.

     * Undo: Ctrl-z.

     * Search (within the field): Ctrl-f.

   Click the 'Save' button (at the bottom) when you're finished, this will
   take you back to the last screen. A yellow bar at the top will confirm
   that the item has been modified, which means that the information has been
   saved.

   The functions described above apply to all fields in the entire CMS where
   formatting is possible.

=====================
Modifying the Content
=====================

   When completing/modifying the content it's essential to first consider
   which structure you will give your Survey. With structure we mean: which
   main modules and/or submodules with questions will there be?

   The Survey can contain main modules and submodules. 'Sub-submodules' are
   not possible.

   Within a module you can either add submodules or risks, a combination of
   both isn't possible. You can however add risks to a submodule.

   When you base the Survey on an existing Survey, it will already have a
   structure. Main modules and/or submodules can be added to, or removed from
   this structure. You can also copy and move modules, both within the Survey
   and to other Surveys under your management (see the overview on the left).

   Click on the module/risk which you want to copy or move, and open the menu
   'Actions' (top right). Choose the desired option, go to the area where you
   want to move it (click in the desired Survey and folder) and choose
   'Paste' in the Action menu.

   How can you determine the structure?

   When using an existing Survey as a starting point, you should study the
   structure and adjust it where required.

   The structure of a base-Survey is as follows:

   Main modules:

   1. [The building : ] Every building.

   2. [The building : ] Certain buildings.

   3. [The building : ] Storage/ warehouse.

   4. [Type of work : ] Office work.

   5. [Type of work : ] Supply and transport of material.

   6. [Type of work : ] Physical work.

   7. [Type of work : ] Working on location.

   8. [Type of work : ] Working with customers / clients / guests.

   9. [Special circumstances : ] Sound.

   10. [Special circumstances : ] Climate: warmth, radiation, cold, outside.

   11. [Special circumstances : ] Vibrations.

   12. [Special circumstances : ] Dangerous substances as raw material.

   13. [Special circumstances : ] Dangerous substances caused by / during
       work.

   14. [Special circumstances : ] Heights / crawl spaces / closed spaces.

   ['Remaining' modules : ]

   15. Tools / machines / means of transport.

   16. In emergencies.

   17. Work and resting periods.

   18. Tasks / functions of colleagues.

   19. Undesirable behaviour of colleagues.

   20. Basic agreements on working conditions.

   21. Providing information.

   22. Agreements on absence.

   23. Agreements on working conditions.

   24. Accidents.

   25. Progress of the Plan of Action.

   In summary: a basic Survey only contains main modules, 25 in total.

   A sector Survey can also contain submodules.

   The questions (statements) are inside the (sub)modules.

   In the base-Survey it's easy to add main modules to the CMS (half way
   through or at the end) or to create more submodules under existing main
   modules.

   It's also easy to delete main modules through the Action menu (top right)
   or move them up or down by dragging them.

   It's worth noting that in practice most sectors mainly expand and/or
   further specify the sections: 'Type of Work' (module 4-8), 'Special
   circumstances' (9-14) and occasionally 'The Building' (1-3), when
   modifying the basic Survey.

   Now you can complete the Survey with modules, submodules, questions
   (risks) and measures (solutions).

   In short:

     * Main page Survey

        * Modules
          
          - Profile module 'optional' (Do you have a store?)
          - Profile module 'repeatable' (for multiple establishments)
          - Module 'optional' (filter question: Do you use dangerous substances?)
          - Module 'customary' (obligatory module)

           * Submodules (optional)

             - Questions (risks)
             - Measures (solutions)

   NB: Terms used in the above example will be further clarified in the
   following chapters

======================
Working with a Profile
======================

   When determining which main modules and potential submodules should be
   created, it's important to consider the option of using a so-called
   'Profile', a 'profile question' is asked before one starts the Survey. It
   is used to determine the main sections, activities, etc. of the company.
   For example, for the Bakery owner:

     * Do you have a store?

     * Do you have a stall at the market?

     * Do you own a sales truck?

   When the end-user answers with 'Yes', the submodules/questions are
   activated. The answer 'No' does not activate the submodules/questions.
   Apart from this, the end-user will be required to complete a certain
   number of 'obligatory' modules.

   In addition, it's possible for the end-user to indicate ownership of more
   than one 'object' referred to in the profile (e.g. multiple stores,
   stalls, sales trucks). In this case the end-user can create an Survey for
   each store/stall/etc., by answering the applicable modules for each
   separate item.

   Using a profile is particularly useful in sectors, where it's probable
   that a substantial number of modules with questions aren't relevant to all
   companies. If you expect that most companies will complete practically all
   modules, creating a profile will be unnecessary unless you would like to
   have the possibility of completing part of the modules multiple times (as
   in the example with the multiple stores).

   In addition you can add submodules and questions (risks) to the profile
   (module). When someone replies with 'No' to an optional profile question,
   all subsequent questions will be nullified (when you don't own a market
   stall, these questions won't be shown). If someone replies with 'Yes'
   (read: checks the box), then all the applicable questions will be shown.

   This module you can thus further complete as a 'normal' module.

======================================
Working with optional (filter) modules
======================================

   Instead of determining which modules apply to the end-user through asking
   profile questions, there's also the possibility of initially offering all
   modules. The first question of a module will then be, if this module will
   be applicable to the end-user. We do this by asking a 'filter question',
   for instance a statement such as: 'Dangerous substances are used'. As
   such, the end-user will initially deal with the module 'Dangerous
   substances', but if they answer with 'No' to this statement the other
   questions won't appear and the end-user will then be moved on to the next
   module. It isn't possible to skip questions by answering 'Yes' to a filter
   question, only by answering 'No'.

   If a filter question in a main module is answered with 'No', any potential
   submodules will also be skipped. It's also possible to start submodules
   with a filter question. A combination of a main module with a filter
   question and related submodules with further filter questions ('nested
   filter questions'), is possible.

   Filter questions are not allowed to refer to potential risk, they only
   determine whether something is applicable or not. This is why a filter
   question can't offer solutions for dealing with a risk and can never cover
   a 'Top 5 risk'. A filter question can only be implemented at the start of
   a module, it's not possible to ask a filter question half way through a
   module, and will always skip the rest of that module. Other ways of
   'jumping through' within a set of questions are not possible.

   Only one filter question may be used in a (sub)module. This is always the
   first question of the module. When there is a necessity to ask a 'double
   filter question', it's best solved by amalgamating the two questions and
   adding an explanation of what happens when one answers with 'Yes' or 'No'.

   Example: 'Physically demanding activities occur AND the prevention
   programme for physical strain has not yet been fully implemented.'

   Answer with 'Yes' when physically demanding activities occur AND the
   prevention programme for physical strain has not yet been fully
   implemented. Otherwise answer with 'No'.

   Thus, to achieve this effect (i.e. skipping inapplicable questions) it
   isn't necessary to create a profile.

   It's useful to start determining which modules could or should start with
   a filter question during the preparation of the module structure.

----------------------------------
Formulating questions (statements)
----------------------------------

   The risks and optional modules (filter question) have the form of
   statements. Avoid words such as not / no / never in the statement (and
   also in profile questions). Given that the end-user can only answer with
   'Yes' or 'No', a statement containing the word 'not' and the answer 'No'
   can lead to confusion. Reformulate for instance as follows:

   'There is no asbestos in the building' -> 'The building is free of
   asbestos'.

   When reformulation is not a possibility, try to clarify with an
   explanation what will happen when the end-user answers with 'No', e.g.:
   'By answering 'No', there is a risk, when answering 'Yes', there is no
   risk'.

   For all statements, the answer 'No' always indicates that there's a risk
   and the answer 'Yes' indicates there isn't a risk. For optional modules
   (filter question) 'No' always leads to skipping questions and 'Yes' to
   continuing with the first question.

   Any answers other than 'Yes' and 'No' are not possible, except for
   temporarily skipping the question ('parking' it) during the survey (when
   the end-user doesn't know the answer immediately). In addition it's
   possible to offer the option 'Not Applicable', if necessary (see below for
   the procedure). This is useful for questions of which you can't predict
   whether they will be relevant to the end-user. Using the optional (filter)
   modules should however, to a large extent, avoid the end-user being
   presented with irrelevant questions.

=================================================
Module structure ready? Get started with the CMS!
=================================================

   When the module structure is clear and the decision has been made whether
   a profile will be used or not, it's a good idea to first completely
   implement the module structure into the CMS. Only after that should you
   add the questions to the modules. It's not useful to start adding
   questions to modules when the structure has not yet been determined.

----------------
Creating Modules
----------------

   You can create modules as follows: click on the top level of the Survey
   (top link in the navigation tree on the left-hand side) and in the grey
   bar underneath the title you will find the button 'Add Profile Question'
   and 'Add Module'.

   .. image:: images/editor/editor_9_creating_modules.png

   For a profile question you will see the following page:

   .. image:: images/editor/editor_10_profile_question.png

   Here you can add:

     * Title: the title of this module, for instance 'Working Circumstances',
       'Acquisition' or 'Physical Strain', etc. The end-user will see this
       title at the top of the page for the duration of answering this
       module's questions. Don't put a full stop after the title. A number
       isn't needed either, the module will be numbered automatically.

     * Description: a short description of this module.

     * Type:- optional: when you would like this module to start with a
       filter question.- repeatable: when you would like to offer this module
       multiple times (e.g. per establishment).For more information on this
       choice, see chapter 4.

   For a module you will see the following page:

   .. image:: images/editor/editor_11_add_module.png

   Here you can add:

     * Title: the title of this module, for instance 'Working Circumstances',
       'Acquisition' or 'Physical Strain', etc. The end-user will see this
       title at the top of the page for the duration of answering this
       module's questions. Don't put a full stop after the title. A number
       isn't needed either, the module will be numbered automatically.

     * Description: a short description of this module.

     * This module is optional: check this box when you want this module to
       start with a filter question.

     * Question: only add a question when this is an optional module. Ask the
       question in such a way, that it is easy to provide an answer: 'Yes'
       means answering all the questions in this module, 'No' means skipping
       all the questions in this module. For more information see chapter 5:
       'Optional Modules'.

     * Image: when applicable you can add an image.

     * --> Introduction Action Plan: when required you can
       add a general text which will be shown at the start of this module.

     * Click on 'Save' at the bottom of the screen.

   To add more main modules, again click on the top link in the navigation
   tree and select the button 'New Module'.

   To add a submodule to the current module, click on the module to which you
   want to add a submodule and select 'New Module'.

   You can modify the modules at a later stage by using the 'Edit' button.
   With the Action menu (top right) you can cut, copy and delete modules and
   by dragging them (up or down) you can change their sequence.

-------------------
Add questions/risks
-------------------

   A question is always placed inside a module. You first select the required
   module on the left-hand side. Don't add risks in the top level of the
   Survey, only in the modules or submodules underneath.

   Open the required module and click on 'Add Risk' in the grey bar
   underneath the title.

   You will then see the screen below:

     .. image:: images/editor/editor_12_add_risk.png

     * Statement: the statement starts with a capital letter. For example:
       'Dangerous substances are used', or 'The building is free of
       asbestos'. Put a full stop after the statement.

     * Problem description: this is the opposite of a statement as referred
       to in the Plan of Action, for example: 'The building is not free of
       asbestos', or 'The building contains asbestos'.

     * Description: describe the risk. Refer to all relevant information
       which can aid the end-user in completing the Survey. For example, a
       clarification/explanation of the exact meaning of 'timely inspection',
       or a reference to more information (e.g. the manual on employment
       means).

     * Legal and Policy References: you can provide the name, number and
       further details of the article or regulation in relation to the
       statement, for example (hypothetical): 'Employment Law, 1998 Art.
       12.3'. You can also place the actual text of that article (preferably
       not too long) within the field.

     * --> Identification: offering, in addition to
       'Yes'/'No', the possibility to answer with 'Not Applicable' by
       checking a box.

-------------------------
Specify evaluation method
-------------------------

   You will see three possibilities for the evaluation:

     * Risk

     * Policy

     * Top 5

Policy risk
-----------

   This concerns a question about policies (e.g. employment policy, sickness
   absence) or procedures (e.g. acquisition). The end-user isn't asked to
   specify a priority here, when 'Policy risk' is selected this standard will
   automatically be prioritised and doesn't have to be added to the
   evaluation. This will, of course, be referred to again in the Plan of
   Action.

Top 5 risk
----------

   A top 5 risk is determined by the sector and is a high risk by definition.
   Here too, the end-user won't be asked to prioritise and it will be
   incorporated into the Plan of Action with a high priority.

Risk
----

   This is different from the 'normal' risks which can occur inside the
   working area or during a working procedure. At this stage it isn't clear
   how high the risk is. You can ask the end-user to specify how high the
   risk is in two ways:

     * Calculated

       In this case the end-user will be asked three questions, if
       the risk is applicable, relating to: probability - frequency -
       severity (see image below)

   .. image:: images/editor/editor_13_evaluation_risk.png

   The questions for probability - frequency - severity are (in the
   program):

   How high is the probability that this risk will occur?

     * Small

     * Medium

     * Large

   How often is one exposed to this risk?

     * Almost never

     * Regularly

     * Constantly

   What is the severity?

     * Weak severity

     * Significant severity

     * High (very high) severity

   The program then calculates the level of the risk and it's priority in
   relation to the answers.

   You can help the end-user by pre-selecting the probability - frequency -
   severity options, according to your sector. The end-user will then be
   shown these options and can adapt them, if required. If you're unsure, or
   if you want the end-user to evaluate this individually, add 'No default'.
   The end-user will then see 'blank' bullet points in the evaluation.

     * Estimated

       Select 'Estimated' when a calculation isn't necessary or
       possible. Here, you can also make an advance suggestion.

       .. image:: images/editor/editor_14_risk_evaluation_estimated.png

Image
-----

   On the risk page you can add images. You will have to upload these
   yourself. Make sure that the images are clear and legible, not too large
   in surface size (maximum 300 x 300 pixels on the screen) and file size
   (maximum 100 kB). Give the image a clear file name, without spaces (for
   example: Danger_logo.jpg). When the image is ready to upload, you select
   it from your computer by using the 'Browse' button. The location and file
   name will appear in the field.

   This function will only allow you to upload images with a 'gif' or 'jpeg'
   extension. Any other files will first have to be placed onto a website and
   can be linked to from the text.

   After uploading the image, click on 'Save' (at the bottom of the page).

   You can modify the risks at a later stage by using the 'Edit' button. With
   the Action menu (top right) you can cut, copy and delete modules and by
   dragging them (up or down) you can change the sequence. You should do this
   before the Survey has been published.

--------------------
Solutions / measures
--------------------

   When the end-user answers at least one content question with 'No', it will
   be addressed in the Action Plan of the Survey (this does not apply to
   filter questions). A specific solution may be related to this question,
   which you can provide (see below). The end-user can also enter a potential
   solution into the program themselves. It will however be most comfortable
   for the end-user if you provide a solution for each question. You're able
   to combine (or replace) the solutions-per-question-level with the
   solutions-per-module-level. We call these 'Action Plans'.

   When at least one question within a module has been answered with 'No',
   the end-user will first see the potential Action Plan for this module in
   the Plan of Action (i.e. a list with tips and tricks). Afterwards, the
   end-user will define concrete solutions for each potential issue within
   the module (based on individual measures or measures provided by you).
   Therefore, the Action Plan is considered to be only introductory.

   You can add an Action Plan in the CMS. --> When you don't
   work with solutions-per-question-level an Action Plan is needed, when you
   do work with solutions-per-question-level it is optional.

   We will first explain how you create an Action Plan (for a module) when
   you don't provide solutions per question.

   You open the module concerned and add a general text for 'Action Plan'.

   We recommend to always start the text of an Action Plan with something
   like:

   Action Plan: When dealing with the risks you can use the following
   solutions:

    1. . . .

    2. . . .

   Make sure to use the word 'Action Plan' in your text.

   When you would like to add multiple tips to a module you can use
   (numbered) bullet points. You can do this with the grey formatting bar
   above the field, the use of which has been explained earlier in this User
   Manual.

   A module containing only a filter question does not require an Action
   Plan.

   An Action Plan related to a main module is not provided to the end-user
   again at each potential submodule.

   When you're finished, you click on the button 'Save'. You will then see a
   conformation in red: 'Changes Saved'.

---------------------------------
Solutions/measures - per question
---------------------------------

   In addition to solutions per module level, it would be ideal if you would
   create solutions for all questions (except for filter questions). You can
   do this as follows.

   A solution is related to a concrete question. First select the
   question/risk in the correct module and then click on 'Add
   Measure' in the grey bar.

   You will see a new screen with blank fields:

     .. image:: images/editor/editor_15_add_measure.png

     * Title: this isn't necessary for a measure. In the CMS it will
       automatically get the title 'Measure 1' (and so on) but this won't be
       visible in the field.

     * Description: start with words which reflect the core message of the
       measure, for example: 'Information and Instruction', and then offer
       the rest of the solution. This text helps to get the end-user started
       and explains the possibilities. In this field you can format the text
       and include links to documents or websites. If you would like to
       include an image, you can do this at the risk itself.

   This text will not be incorporated into the Plan of Action.

     * --> General approach (to eliminate or reduce the risk): a short description of what the
       end-user can do to limit the risk. This text will be incorporated into
       the Plan of Action. For example: 'Ensure the correct means of Personal
       Protection are used, according to...'. If the end-user selects this
       measure it will be copied over to the Plan of Action.

     * Specific action(s) required to implement this approach: a suggestion of what the end-user can do to prevent
       the risk from reoccurring. For example: 'Purchase a new machine which
       produces less sound/dust'.

   If the end-user selects this measure it will be copied over to the Plan of
   Action.

     * Level of expertise and/or requirements needed: any extra requirements which are necessary to limit or
       prevent the risk can be named here. For example: budgeting, training
       for Prevention/Safety staff, incorporating this subject in team
       meetings, etc.

   If the end-user selects this measure it will be copied over to the Plan of
   Action.

   Click on 'Save' at the bottom of the page.

   You can add more standard measures for each risk if needed, by clicking on
   the button 'Add Measure'.

--------------------
Checking your Survey
--------------------

   When all the work has been done, i.e. the structure, contents and profile
   have been completed, you can view your Survey (prior to making it public).

   This is done by clicking 'Preview' in the 'Versions drawer'. The online program with your
   (unpublished) Survey will be shown in a new window.

   To view the preview you will have to register, the end-user will have to
   undertake the same action when starting the Survey. After registering, you
   can complete the Survey as an end-user.

   Tip: check as many boxes as possible in the profile, answer the filter
   questions with 'Yes' and the risks with 'No'. This way you will view all
   questions and possibilities.

   When you discover faults in the preview you can amend these in the CMS.
   Access the Preview again to check your modifications.

   NB: The preview is stored in a separate place on the server, it won't be
   viewable to the end-users until you publish the Survey.

---------------------------------------------------------
Implementing your company logo and design into the Survey
---------------------------------------------------------

   Straight after logging into the CMS, you go to the 'Settings' menu (top
   right).

   You will see the following screen:

   .. image:: images/editor/editor_16_selecting_colours.png

   Here you can select the two most important colours: a main colour and a
   supporting colour. You can do this by clicking on the white circle (don't
   let go of it!) and dragging this to the colour of your choice. You will
   immediately see the effect on the logo at the top.

   You can also enter the colour code into the Hex-field underneath.

   General Advice:

   It's recommended to let a designer determine the colours, who can ensure
   amongst other things that:

     * Appearance is clearly identifiable with the sector.

     * Legibility of the text (the Survey end-user will often have to read
       large portions of text).

     * Forms of colour blindness (at 10% of the male population) are taken
       into account.

Logo
----

   One sector logo can be placed at the top left of the program. If you want
   to include several logos, you will have to amalgamate these into one
   image.

   .. image:: images/editor/editor_17_logo_upload.png

   For best results, take a transparent 'PNG' file with a height of at least
   110 pixels. Larger logos will be resized automatically.

   Place the logo at your sector as follows:

   Under 'Logo' you check the box 'My logo', you then click on 'Browse' next
   to 'Choose file' to navigate to your own computer. To upload the image and
   link it to your own Survey, click on --> 'Save' at the
   bottom of the page. You can change the image at a later date if need be,
   or opt for the standard logo.

---------------
Ready? Publish!
---------------

   Once you've successfully completed all steps it's time to publish your
   Survey.

   When you click on 'Publish', the Survey will be made available.

   Note: it can take some time to perform this action.

   A confirmation will appear in a green bar:

   .. image:: images/editor/editor_18_publish_survey.png

   From now on, the public can view and complete your Survey. If it's a new
   Survey we would like to be notified (info@osha.europa.eu), and will put
   the link onto our site: www.oira.osha.europa.eu. You don't have to notify
   us when you've updated the Survey.

============================
Modifying an existing Survey
============================

   The chapters prior to this are based on creating a new Survey, potentially
   on the basis of an existing Survey.

   Naturally the process of creating an Survey will be followed by managing
   and maintaining your Survey. In actuality, the exact same considerations,
   focus points and functionalities apply to this process.

   After adapting the Survey you check it with the Preview and then publish
   it, as described above.

-----------
Logging out
-----------

   Don't forget to logout when you stop working in the CMS. This is done with
   the button at the top right: click on your login name and select 'Logout'.
   After logging out successfully, you will be brought back to the login
   screen where you will see the notification 'Logout successful'.

============================
Where can you ask questions?
============================

   Direct your questions to:

   Online Interactive Risk Assessment, EU-OSHAinfo@osha.europa.eu

   We wish you all the best with creating your Digital Survey.

   The EU-OSHA OiRA Team


